@@ -41,18 +41,19 @@ def display(
     zoom_syncs=[],
     host='localhost',
     server_port=None,
+    dark_mode=False,
     log_level=logging.ERROR
 ):
     '''
     Instantiate a HiGlass display with the given views
     '''
     from .server import Server
-    from .client import ViewConf
+    from .client import CombinedTrack, View, ViewConf
     tilesets = []
 
     for view in views:
         for track in view.tracks:
-            if track.tracks:
+            if hasattr(track, 'tracks'):
                 for track1 in track.tracks:
                     if track1.tileset:
                         tilesets += [track1.tileset]
@@ -63,24 +64,35 @@ def display(
     server = Server(tilesets, host=host, port=server_port)
     server.start(log_level=log_level)
 
-    for view in views:
-        for track in view.tracks:
-            if track.tracks:
-                for track1 in track.tracks:
-                    if ('server' not in track1.viewconf or
-                            track1.viewconf['server'] is None):
-                        track1.viewconf['server'] = server.api_address
-            else:
-                if ('server' not in track.viewconf or
-                        track.viewconf['server'] is None):
-                    track.viewconf['server'] = server.api_address
+    cloned_views = [View.from_dict(view.to_dict()) for view in views]
 
-    conf = ViewConf(
-        views,
+    for view in cloned_views:
+        for track in view.tracks:
+            if isinstance(track, CombinedTrack):
+                for track1 in track.tracks:
+                    if ('server' not in track1.conf or
+                            track1.conf['server'] is None):
+                        track1.conf['server'] = server.api_address
+            else:
+                if ('server' not in track.conf or
+                        track.conf['server'] is None):
+                    track.conf['server'] = server.api_address
+
+    viewconf = ViewConf(
+        cloned_views,
         location_syncs=location_syncs,
         zoom_syncs=zoom_syncs)
 
-    return (HiGlassDisplay(viewconf=conf.to_dict()), server, conf)
+    return (
+        HiGlassDisplay(
+            viewconf=viewconf.to_dict(),
+            hg_options={
+                'isDarkTheme': dark_mode
+            }
+        ),
+        server,
+        viewconf
+    )
 
 
 def view(tilesets):
